JobResource class

Constructors

JobResource(LetItClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createWithCompany({required String companyName, required String companyDescription, required String companyWebsite, required String jobTitle, required String jobDescription, required String jobHowToApply, bool jobPayInCryptocurrency = false, JobLocation jobLocation = JobLocation.remote}) Future<UserJobCreatedByUser>
delete(String slug) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited