MicropostResource class

Constructors

MicropostResource(LetItClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required String body, String? title, PostType postType = PostType.text, bool allowComments = true, bool isDraft = false, FilePayload? file}) Future<CreatedWithPublicIdAndLink>
delete(String publicId) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited